@@ -8,11 +8,11 @@ use Archive::Har::Browser();
 use Archive::Har::Page();
 use Archive::Har::Entry();
 use XML::LibXML();
+use Compress::Zlib();
 use JSON();
-use Carp();
 use overload '""' => 'string';
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -31,6 +31,13 @@ sub _init {
     return;
 }
 
+sub gzip {
+    my ( $self, $string ) = @_;
+    my $gzipped = Compress::Zlib::memGzip( $self->string() )
+      or Carp::croak("Failed to gzip HAR archive");
+    return $gzipped;
+}
+
 sub string {
     my ( $self, $string ) = @_;
     my $old =
@@ -450,7 +457,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -479,13 +486,17 @@ Archive::Har->new() will return a new har object, ready to process http archives
 
 $har->string() accepts a stringified version of an L<http archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  It returns the previous state of the archive in stringified form
 
+=head2 gzip
+
+$har->gzip() returns a gzipped copy of the current state of the archive in stringified form
+
 =head2 xml
 
-$har->xml() accepts a stringified version of Internet Explorer's Network Inspector XML export and parses it.  There is no return value.
+$har->xml() accepts a stringified version of Internet Explorer's Network Inspector XML export and parses it.  There is no return value
 
 =head2 version
 
-$har->version() will return the version of the HTTP Archive ('1.1' by default);
+$har->version() will return the version of the HTTP Archive ('1.1' by default)
 
 =head2 creator
 
@@ -501,7 +512,7 @@ $har->pages() will return the list of L<page|Archive::Har::Page> objects for the
 
 =head2 entries
 
-$har->entries() will return the list of L<entry|Archive::Har:Entry> objects for the HTTP Archive
+$har->entries() will return the list of L<entry|Archive::Har::Entry> objects for the HTTP Archive
 
 =head2 comment
 
