@@ -1,10 +1,11 @@
 package Archive::Har::Entry::Cookie;
 
-use JSON();
 use warnings;
 use strict;
+use JSON();
+use Carp();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -178,7 +179,7 @@ Archive::Har::Entry::Cookie - Represents a single http cookie object for a reque
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
