@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Header();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -56,7 +56,7 @@ sub comment {
 sub AUTOLOAD {
 	my ($self, $new) = @_;
 
-	my $name = $Archive::Har::Page::PageTimings::AUTOLOAD;
+	my $name = $Archive::Har::Entry::Header::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
 	my $old;
@@ -96,7 +96,7 @@ Archive::Har::Entry::Header - Represents a single http header object for a reque
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -116,6 +116,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Header object
+
 =head2 name
 
 returns the name of the http header
