@@ -2,9 +2,10 @@ package Archive::Har::Entry::Request::PostData;
 
 use warnings;
 use strict;
+use Carp();
 use Archive::Har::Entry::Request::PostData::Params();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -128,7 +129,7 @@ Archive::Har::Entry::Request::PostData - Represents a single name/value pair fro
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -151,6 +152,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new PostData object
+
 =head2 mime_type
 
 returns the mime type of the posted data
@@ -161,9 +166,9 @@ returns the plain text posted data.  It will return undef if params has been def
 
 =head2 params
 
-returns a list of posted parameters
+returns a list of L<posted parameters|Archive::Har::Entry::Request::PostData::Params>
 
 =head2 comment
 
-returns the comment about element in the Query String
+returns the comment about the Post Data
 
