@@ -2,8 +2,9 @@ package Archive::Har::Entry::Request::PostData::Params;
 
 use warnings;
 use strict;
+use Carp();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -98,6 +99,12 @@ sub TO_JSON {
 	my $json = { };
 	$json->{name} = $self->name();
 	$json->{value} = $self->value();
+	if (defined $self->file_name()) {
+		$json->{fileName} = $self->file_name();
+	}
+	if (defined $self->content_type()) {
+		$json->{contentType} = $self->content_type();
+	}
 	if (defined $self->comment()) {
 		$json->{comment} = $self->comment();
 	}
@@ -119,7 +126,7 @@ Archive::Har::Entry::Request::PostData::Params - Represents a single name/value
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -144,6 +151,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Params object
+
 =head2 name
 
 returns the name of the parameter in the posted data
