@@ -2,8 +2,9 @@ package Archive::Har::Entry::Request::QueryString;
 
 use warnings;
 use strict;
+use Carp();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -54,7 +55,7 @@ sub comment {
 sub AUTOLOAD {
 	my ($self, $new) = @_;
 
-	my $name = $Archive::Har::Page::PageTimings::AUTOLOAD;
+	my $name = $Archive::Har::Entry::Request::QueryString::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
 	my $old;
@@ -94,7 +95,7 @@ Archive::Har::Entry::Request::QueryString - Represents a single name/value pair
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -114,6 +115,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new QueryString object
+
 =head2 name
 
 returns the name of the element in the Query String
