@@ -7,7 +7,7 @@ use Archive::Har::Entry::Header();
 use Archive::Har::Entry::Cookie();
 use Archive::Har::Entry::Response::Content();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -160,6 +160,15 @@ sub body_size {
 	}
 }
 
+sub comment {
+	my ($self, $new) = @_;
+	my $old = $self->{comment};
+	if (@_ > 1) {
+		$self->{comment} = $new;
+	}
+	return $old;
+}
+
 sub AUTOLOAD {
 	my ($self, $new) = @_;
 
@@ -200,6 +209,9 @@ sub TO_JSON {
 		$json->{bodySize} = -1;
 	}
 	$json->{bodySize} += 0;
+	if (defined $self->comment()) {
+		$json->{comment} = $self->comment();
+	}
 	foreach my $key (sort { $a cmp $b } keys %{$self}) {
 		next if (!defined $self->{$key});
 		if ($key =~ /^_[[:alnum:]]+$/smx) { # private fields
@@ -217,7 +229,7 @@ Archive::Har::Entry::Response - Represents a single http response inside the HTT
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -244,6 +256,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Response object
+
 =head2 status
 
 returns the numeric status of the response
@@ -258,15 +274,15 @@ returns the version of the http response
 
 =head2 headers
 
-returns a list of http header objects
+returns a list of L<http header|Archive::Har::Entry::Header> objects
 
 =head2 cookies
 
-returns a list of http cookie objects
+returns a list of L<http cookie|Archive::Har::Entry::Cookie> objects
 
 =head2 content
 
-returns details about the response body
+returns L<details|Archive::Har::Entry::Response::Content> about the response body
 
 =head2 redirect_url
 
