@@ -2,8 +2,9 @@ package Archive::Har::Entry::Response::Content;
 
 use warnings;
 use strict;
+use Carp();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -98,7 +99,7 @@ sub comment {
 sub AUTOLOAD {
 	my ($self, $new) = @_;
 
-	my $name = $Archive::Har::Page::PageTimings::AUTOLOAD;
+	my $name = $Archive::Har::Entry::Response::Content::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
 	my $old;
@@ -107,7 +108,6 @@ sub AUTOLOAD {
 		if (@_ > 1) {
 			$self->{$name} = $new;
 		}
-		return $self->{$name};
 	} else {
 		Carp::croak("$name is not specified in the HAR 1.2 spec and does not start with an underscore");
 	}
@@ -141,9 +141,6 @@ sub TO_JSON {
 	return $json;
 }
 
-sub DESTROY {
-}
-
 1;
 __END__
 =head1 NAME
@@ -152,7 +149,7 @@ Archive::Har::Entry::Response::Content - Represents the content for a response i
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -174,6 +171,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Content object
+
 =head2 size
 
 returns the length of the returned content in bytes
