@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Cache::Request();
 
-our $VERSION = 0.09;
+our $VERSION = '0.10';
 
 sub new {
 	my ($class, $params) = @_;
@@ -94,7 +94,7 @@ sub send {
 	my ($self, $new) = @_;
 	my $old = $self->{send};
 	if (@_ > 1) {
-		$self->{send} = $new + 0;
+		$self->{send} = $new;
 	}
 	return $old;
 }
@@ -103,7 +103,7 @@ sub wait {
 	my ($self, $new) = @_;
 	my $old = $self->{wait};
 	if (@_ > 1) {
-		$self->{wait} = $new + 0;
+		$self->{wait} = $new;
 	}
 	return $old;
 }
@@ -112,7 +112,7 @@ sub receive {
 	my ($self, $new) = @_;
 	my $old = $self->{receive};
 	if (@_ > 1) {
-		$self->{receive} = $new + 0;
+		$self->{receive} = $new;
 	}
 	return $old;
 }
@@ -122,7 +122,7 @@ sub ssl {
 	my $old = $self->{ssl};
 	if (@_ > 1) {
 		if (defined $new) {
-			$self->{ssl} = $new + 0;
+			$self->{ssl} = $new;
 		} else {
 			$self->{ssl} = -1;
 		}
@@ -146,7 +146,7 @@ sub comment {
 sub AUTOLOAD {
 	my ($self, $new) = @_;
 
-	my $name = $Archive::Har::Page::PageTimings::AUTOLOAD;
+	my $name = $Archive::Har::Entry::Timings::AUTOLOAD;
 	$name =~ s/.*://smx;   # strip fully-qualified portion
 
 	my $old;
@@ -165,25 +165,25 @@ sub TO_JSON {
 	my ($self) = @_;
 	my $json = {};
 	if (defined $self->blocked()) {
-		$json->{blocked} = $self->blocked();
+		$json->{blocked} = $self->blocked() + 0;
 	} else {
 		$json->{blocked} = -1;
 	}
 	if (defined $self->dns()) {
-		$json->{dns} = $self->dns();
+		$json->{dns} = $self->dns() + 0;
 	} else {
 		$json->{dns} = -1;
 	}
 	if (defined $self->connect()) {
-		$json->{connect} = $self->connect();
+		$json->{connect} = $self->connect() + 0;
 	} else {
 		$json->{connect} = -1;
 	}
-	$json->{send} = $self->send() || 0;
-	$json->{wait} = $self->wait() || 0;
-	$json->{receive} = $self->receive() || 0;
+	$json->{send} = ($self->send() || 0) + 0;
+	$json->{wait} = ($self->wait() || 0) + 0;
+	$json->{receive} = ($self->receive() || 0) + 0;
 	if (defined $self->ssl()) {
-		$json->{ssl} = $self->ssl();
+		$json->{ssl} = $self->ssl() + 0;
 	} else {
 		$json->{ssl} = -1;
 	}
@@ -200,9 +200,6 @@ sub TO_JSON {
 	return $json;
 }
 
-sub DESTROY {
-}
-
 1;
 __END__
 =head1 NAME
@@ -211,7 +208,7 @@ Archive::Har::Entry::Timings - Represents the timings for the individual phases
 
 =head1 VERSION
 
-Version 0.09
+Version '0.10'
 
 =head1 SYNOPSIS
 
@@ -234,6 +231,10 @@ Version 0.09
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+returns a new Timings object
+
 =head2 blocked
 
 returns the time in milliseconds spent waiting for a network connection.  Ihe function will return undef if it does not apply to the current request
